
{$DEFINE DEBUG}

unit EmptyBtn;

interface

uses ActiveX, TlbPdk, Windows, EmptyAboutFrm, EmptyPropsFrm, SysUtils, Controls, Dialogs, Classes;

const
  CLSID_EmptyBtn: TGUID = '{fa36e301-49d8-4743-994f-dde805cc616f}';
  Desc_EmptyBtn = 'Empty Button';

type
  TEmptyBtn = class(TTlbButton)
  public
    procedure Initialize; override;
    destructor Destroy; override;
    function GetSupportedActions: LongWord; override;
    function OnCreate: Boolean; override;
    function OnAbout: Boolean; override;
    function OnProperties: Boolean; override;
    function Load(const data: IStream): Boolean; override;
    function Save(const data: IStream): Boolean; override;
    procedure OnHotKey(hkID: LongWord); override;
  end;

implementation

uses ComServ;

procedure TEmptyBtn.Initialize;
begin
  {$IFDEF DEBUG}OutputDebugString('Initialize');{$ENDIF}
  inherited Initialize;
  with ToolTip do begin
    Caption := 'Empty Button';
    Text := 'Simple Description';
    Icon := LoadIcon(HInstance, 'EmptyIcon');
  end;
end;

destructor TEmptyBtn.Destroy;
begin
  {$IFDEF DEBUG}OutputDebugString('Destroy');{$ENDIF}
  DestroyIcon(ToolTip.Icon);
  inherited Destroy;
end;

function TEmptyBtn.GetSupportedActions: LongWord;
begin
  Result := CTMS_PROPERTIES or CTMS_ABOUT;
end;

function TEmptyBtn.OnCreate: Boolean;
begin
  Result := OnProperties;
end;

function TEmptyBtn.OnAbout: Boolean;
var
  AboutFrm: TAboutFrm;
begin
  AboutFrm := TAboutFrm.CreateParented(TlbContainer.GetBandWND);
  try
    AboutFrm.ShowModal;
  finally
    AboutFrm.Free;
  end;
  Result := True;
end;

function TEmptyBtn.OnProperties: Boolean;
var
  PropsFrm: TPropsFrm;
begin
  PropsFrm := TPropsFrm.CreateParented(TlbContainer.GetBandWND);
  PropsFrm.HotKey.HotKey := HotKey;
  try
    if PropsFrm.ShowModal = mrOK then begin
      HotKey := PropsFrm.HotKey.HotKey;
      TlbContainer.SaveButton;
      Result := True;
    end else
      Result := False;
  finally
    PropsFrm.Free;
  end;
end;

function TEmptyBtn.Load(const data: IStream): Boolean;
var
  pcbRead: LongInt;
  hk: TShortCut;
begin
  data.Read(@hk, SizeOf(hk), @pcbRead);
  HotKey := hk;
  Result := True;
end;

function TEmptyBtn.Save(const data: IStream): Boolean;
var
  pcbWritten: LongInt;
  hk: TShortCut;
begin
  hk := HotKey;
  data.Write(@hk, SizeOf(hk), @pcbWritten);
  Result := True;
end;

procedure TEmptyBtn.OnHotKey(hkID: LongWord);
begin
  MessageDlg('HotKey...', mtInformation, [mbOK], 0);
end;

initialization
  TTlbButtonFactory.Create(ComServer, TEmptyBtn, CLSID_EmptyBtn, Desc_EmptyBtn);
end.
